@@ -392,7 +392,11 @@ class Filepath(type(pathlib.Path())):
             return os.path.join(os.getcwd(), str(path))
 
     def __eq__(self, other):
-        return self._realpath(self) == self._realpath(other)
+        # Use fast cached path if possible
+        if isinstance(other, Filepath):
+            return hash(self) == hash(other)
+        else:
+            return self._realpath(self) == self._realpath(other)
 
     def __hash__(self):
         try:
